@@ -178,7 +178,7 @@ def db_dirty_get( ) :
 #####################################################################
 
 def sql_execute( sql ) :
-    s_log.write( sql )
+    #s_log.write( sql )
     cur = db_con.cursor( )
     cur.execute( sql )
     db_con.commit( )
@@ -229,6 +229,7 @@ def init_schema( ) :
     sql_execute( "CREATE TABLE sys ( sn text UNIQUE , sv text )" )
     sql_execute( "CREATE INDEX index_sys ON sys ( sn )" )
 
+# FIXME TODO add host environment vars e.g. hostname/machine id etc.
     sys_create( "ver_db" , "1.0" )
     sys_create( "ver_sapi" , s_config.get_key( "/config/version" ) )
     sys_create( "serial" , "ODS042e1919c5bd8f41cd8e1a2b8e455dd8f6fb00df0c3916d1137047a7aafc4c42" )
@@ -306,7 +307,7 @@ def sys_update( sn , sv_in ) :
 
 def sys_delete( sn ) :
 
-    sql = "DELETE FROM sys where sn='" + sn + "' limit 1"
+    sql = "DELETE FROM sys where sn='" + sn + "'"
     sql_execute( sql )
     return( True )
 
@@ -374,7 +375,7 @@ def stacks_pop( sk = 0 ) :
     sid = row[ "sid" ]
     sv_dict = json.loads( row[ "sv" ] )
 
-    sql = "DELETE FROM stacks where sid=" + str( sid ) + " limit 1"
+    sql = "DELETE FROM stacks where sid=" + str( sid ) 
     sql_execute( sql )
 
     return( sv_dict )    
@@ -410,7 +411,7 @@ def env_update( en , ev ) :
 
 def env_delete( en ) :
 
-    sql = "DELETE FROM env where en='" + en + "' limit 1"
+    sql = "DELETE FROM env where en='" + en + "'"
     sql_execute( sql )
     return( True )
 
@@ -452,7 +453,7 @@ def meta_update( mn , mv_in ) :
 
 def meta_delete( mn ) :
 
-    sql = "DELETE FROM meta where mn='" + mn + "' limit 1"
+    sql = "DELETE FROM meta where mn='" + mn + "'"
     sql_execute( sql )
     return( True )
 
@@ -496,7 +497,7 @@ def args_update( aid , av ) :
 
 def args_delete( aid ) :
 
-    sql = "DELETE FROM args where aid=" + aid + " limit 1"
+    sql = "DELETE FROM args where aid=" + aid 
     sql_execute( sql )
     return( True )
 
@@ -613,7 +614,7 @@ def files_update( fp ) :
 
 def files_delete( fp ) :
 
-    sql = "DELETE FROM files where fp='" + fp + "' limit 1"
+    sql = "DELETE FROM files where fp='" + fp + "'"
     sql_execute( sql )
 
     return( True )  
@@ -722,7 +723,7 @@ def templates_update( tp , tk , tv ) :
 
 def templates_delete( tp ) :
 
-    sql = "DELETE FROM templates where tp='" + tp + "' limit 1"
+    sql = "DELETE FROM templates where tp='" + tp + "'"
     sql_execute( sql )
     return( True )
 
