@@ -31,6 +31,13 @@ session = requests.Session( )
 
 check_connectivity_done = False
 
+# FIXME TODO - when _CONTAINER_LOCAL_CONFIGENDPOINTKEY=_sapiserver_LOCAL_CONFIGENDPOINTKEY_
+#  File "/usr/local/lib/python3.8/dist-packages/sapiadapter/s_net.py", line 96, in check_connectivity
+#    s_log.write( endpoint_parseurl.hostname + "," + str( endpoint_url_port ) + "," + endpoint_host )
+#TypeError: unsupported operand type(s) for +: 'NoneType' and 'str'
+#EXCEPTION job_get
+
+
 def check_connectivity( ) :
 
     global check_connectivity_done
@@ -81,7 +88,7 @@ def check_connectivity( ) :
 
     ################################################################
 
-    if( flag_networkok and get_request_response( {"X-Omni-Action": "mwget"}) == False ) :
+    if( flag_networkok and get_request_response( { "X-Omni-Action": "check_connectivity" } ) == False ) :
         s_log.write( "False check_connectivity 2" )
         flag_networkok = False
 
@@ -164,10 +171,11 @@ def job_responsewait( jid , timeout = 60 ) :
         if( jr == False ) : return( False )
         if( jr == True ) : return( True )
         if( time.time( ) - time_start ) > timeout : return( None )
-        time.sleep( 0.1 )
 
 def job_response( jid ) :
 
+    time.sleep( 1 )
+
     if( not s_util.ready( ) ) :
         s_log.write( "NOT READY" )
         return( False )
@@ -197,7 +205,7 @@ def job_response( jid ) :
         s_log.write( "job_response !=Done [" + jid + "]" )
         return( None )
 
-    if(len(res.content)==0):
+    if( len( res.content ) == 0) : 
         s_log.write( "ERROR EMPTY RES CONTENT" )
         return( False )
 
@@ -248,7 +256,7 @@ def job_get( ) :
         #s_db.meta_create( "_server_getjob_context_json" , context_json ) 
 
     job_id = res.headers[ "X-Omni-Jid" ]
-    s_config.set_key("jid", job_id ) 
+    s_config.set_key( "jid" , job_id ) 
     s_log.write( "job_get [" + job_id + "]" )
 
     return( True )
@@ -299,63 +307,8 @@ def job_set( ) :
 
 #####################################################################
 
-def mw_get( ) :
-    mw1 = get_mw( )
-    if( mw1 == False ) :
-        s_log.write( "ERROR False get_mw" )
-        return( False )
-    mw = "MWCf068980781d390b52666900ee6d4cce11ac2e9e8e175a9c3293e35659911df5a" + mw1
-    mw = s_util.hash( mw.encode( "utf-8" ) , "MWH" )
-    #s_log.write(mw)
-    return( mw )
-
-def get_mw( ) :
-
-    headers =   {
-                    "X-Omni-Action": "mwget" ,
-                }
-
-    #s_log.write( headers )
-
-    res = get_request_response( headers )
-
-    if( res == False ) :
-        s_log.write( "ERROR get_mw false res" )
-        return( False )
-
-    #s_log.write(str(res.headers))
-
-    if( not "X-Omni-Mw" in res.headers ) :
-        s_log.write( "ERROR Not found X-Omni-Mw" )
-        return( False )
-
-    if( len( res.headers[ "X-Omni-Mw" ] ) != 67 ) :
-        s_log.write( "ERROR X-Omni-Mw!=67" )
-        return( False )
-
-    mw = res.headers[ "X-Omni-Mw" ]
-
-    #s_log.write(mw)
-
-    if( "X-Omni-Wait" in res.headers ) :
-        #s_log.write( "Found X-Omni-Wait " + res.headers[ "X-Omni-Wait" ] )
-        time.sleep( int( res.headers[ "X-Omni-Wait" ] ) )
-
-    return( mw )
-
-#####################################################################
-
 def get_request_response( request_headers = { }  , payload = "" ) :
 
-    # Careful - don't want infinite recursion here!
-    if( "X-Omni-Action" in request_headers ) and ( request_headers[ "X-Omni-Action" ] != "mwget" ) :
-        if not "X-Omni-Mw" in request_headers :
-            mw = mw_get( )
-            if( not mw ) : return( False )
-            request_headers[ "X-Omni-Mw" ] = mw
-
-    ################################################################ 
-
     if not "User-Agent" in request_headers :
         request_headers[ "User-Agent" ] = "sapiadapter"
     if not "X-Omni-Authorization" in request_headers :
@@ -386,7 +339,7 @@ def get_request_response( request_headers = { }  , payload = "" ) :
 
     endpoint_timeout = s_config.get_key( "endpoint/timeout" )
     if endpoint_timeout == None or ( not endpoint_timeout.isdigit( ) ) :
-        endpoint_timeout = 60 
+        endpoint_timeout = 180
     else:
         endpoint_timeout = int( endpoint_timeout )
 
@@ -423,22 +376,21 @@ def get_request_response( request_headers = { }  , payload = "" ) :
 
     #####################################################################
 
-    if( ( response.status_code != 200 ) and ( response.status_code != 418 ) ) :
-        s_log.write( "ERROR status_code" )
-        s_log.write( endpoint_url )
-        s_log.write( request_headers )
-        s_log.write( response.status_code )
-        if( response.status_code == 404 ) :
-            s_log.write( "Check endpoint url" )
-        if( response.status_code == 502 ) :
-            s_log.write( "ERROR 502" )
-
-        return( False )
+    if ( response.status_code == 200 ) :
+        return( response )
 
     #####################################################################
 
-    return( response )
+    s_log.write( "ERROR status_code" )
+    s_log.write( endpoint_url )
+    s_log.write( request_headers )
+    s_log.write( response.status_code )
+    if( response.status_code == 404 ) :
+        s_log.write( "Check endpoint url" )
+    if( response.status_code == 502 ) :
+        s_log.write( "ERROR 502" )
 
-#####################################################################
+    time.sleep( 10 )
 
+    return( False )
     
\ No newline at end of file
