@@ -140,7 +140,7 @@ def printexception( e = False ) :
 
 
 heartbeat_last = 0
-def heartbeat( t = 60 ) :
+def heartbeat( t = 600 ) :
     global heartbeat_last
     time.sleep( 0.01 )
     if( uptime( ) - heartbeat_last ) < t : return( False )
@@ -150,6 +150,7 @@ def heartbeat( t = 60 ) :
 
 def ready( ) :
 
+    # FIXME TODO move this out to function
     config = s_config.get_config( )
     if "/config/init/path_time" in config :
         cd = config[ "/config/cwd" ]
@@ -159,12 +160,15 @@ def ready( ) :
         cfp=cip
         if not os.path.isabs(cip):
             cfp = cd + "/" + cip
-        cipt2 = os.path.getmtime( cfp )
-        if( os.path.getmtime( cfp ) != cipt ) :
-            s_config.setup( )
-            s_db.setup( )
-            s_log.write( "RELOADED " )
-            #s_log.write( "CONFIG RELOADED " + cfp + str( cipt ) )
+
+        if os.path.isfile( cfp ) :
+
+            cipt2 = os.path.getmtime( cfp )
+            if( os.path.getmtime( cfp ) != cipt ) :
+                s_config.setup( )
+                s_db.setup( )
+                s_log.write( "RELOADED " )
+                #s_log.write( "CONFIG RELOADED " + cfp + str( cipt ) )
 
     ####################################################################
 
@@ -186,10 +190,17 @@ def gen_workingdirectory( ) :
 
 def proc_setup( ) :
 
+    app_dir = "/data/app"
+
+    if( not os.path.isdir( app_dir ) ) :
+        s_log.write( "app_dir " + app_dir + " does not exist!")
+        return( False )
+
+
     work_dir = gen_workingdirectory( )
 
     # FIXME TODO should be coming from config
-    shutil.copytree( "/data/app/" , work_dir , ignore = shutil.ignore_patterns( ".git*" ) )
+    shutil.copytree( app_dir , work_dir , ignore = shutil.ignore_patterns( ".git*" ) )
 
     os.chdir( work_dir )
     #print(os.getcwd())
@@ -207,6 +218,8 @@ def proc_setup( ) :
 
     s_db.setup( ) 
 
+    return( True )
+
 def proc_trackcurrentfiles( ) :
 
     procfiles = { }
@@ -318,4 +331,3 @@ def parent_path( ) :
     
 
 
-
