@@ -28,8 +28,7 @@ s_db.setup( )
 
 #####################################################################
 
-
-def test( ) :
+def isready( ) :
 
     if( not s_util.ready( ) ) :
         s_log.write( "ERROR False ready" )
@@ -69,6 +68,9 @@ def server( ) :
 
     while True :
 
+
+        s_log.write("SERVER LOOP")
+
         heartbeat( )
 
         #####################################################
@@ -97,9 +99,9 @@ def server( ) :
         defmeta = s_db.files_defmeta_get( )
         if( "_ping_5800b137d" in defmeta ) :
             #print(defmeta["_ping_5800b137d"])
-            t1 = defmeta["_ping_5800b137d"]
+            t1 = defmeta[ "_ping_5800b137d" ]
             s_db.setup( )
-            defdata=["_ping_5800b137d"] 
+            defdata=[ "_ping_5800b137d" ] 
             defmeta = {
                 "_ping_5800b137d" : "." + t1
             }
@@ -111,7 +113,8 @@ def server( ) :
 
         #####################################################
 
-        s_util.proc_setup( )
+        if( not s_util.proc_setup( ) ) :
+            continue
 
         #####################################################
 
@@ -199,5 +202,6 @@ def run( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    #return( True )
-    return( defdata( ) )
+    dd = defdata( )
+    if( dd==False ) : return(True)
+    return(dd)
